==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-admin/lxqt-admin-user/lxqt-admin-user_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Настройки группы</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Имя группы:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>ID группы:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>Пользователи, относящиеся к этой группе:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <location filename="../groupdialog.cpp" line="92"/>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <source>The group ID is in use.</source>
        <translation>ID группы уже используется.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="92"/>
        <source>The group name cannot be empty.</source>
        <translation>Имя группы не может быть пустым.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>The group name is in use.</source>
        <translation>Имя группы уже используется.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Настройки пользователя и группы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation>&amp;Пользователи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Логин пользователя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>ID пользователя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Полное имя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Домашний каталог</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Показывать системных пользователей (только для продвинутых пользователей)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Группы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>ID группы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Добавить новых пользователей или группы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Удалить выбранный элемент</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>Редактировать свойства выделенного элемента</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Обновить списки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Вы действительно хотите удалить выбранного пользователя?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Вы действительно хотите удалить выбранную группу?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Настройки пользователя</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Полное имя:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Логин пользователя:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Установить пароль:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>ID пользователя:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Главная группа:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Командная оболочка:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Домашний каталог:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="64"/>
        <source>Change password:</source>
        <translation>Изменить пароль:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <location filename="../userdialog.cpp" line="138"/>
        <location filename="../userdialog.cpp" line="143"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <source>The user ID is in use.</source>
        <translation>Пользовательский ID уже используется.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="138"/>
        <source>The user name cannot be empty.</source>
        <translation>Имя пользователя не может быть пустым.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="143"/>
        <source>The user name is in use.</source>
        <translation>Имя пользователя уже используется.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Вы действительно хотите использовать пустой пароль для этого пользователя?</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Настройки группы</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Имя группы:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>ID группы:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>Пользователи, относящиеся к этой группе:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <source>The group ID is in use.</source>
        <translation>ID группы уже используется.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <source>The group name cannot be empty.</source>
        <translation>Имя группы не может быть пустым.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>The group name is in use.</source>
        <translation>Имя группы уже используется.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Настройки пользователя и группы</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation>&amp;Пользователи</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Логин пользователя</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>ID пользователя</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Полное имя</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Домашний каталог</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Показывать системных пользователей (только для продвинутых пользователей)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Группы</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>ID группы</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Добавить новых пользователей или группы</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Удалить выбранный элемент</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>Редактировать свойства выделенного элемента</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Обновить списки</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Вы действительно хотите удалить выбранного пользователя?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Вы действительно хотите удалить выбранную группу?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Настройки пользователя</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Полное имя:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Логин пользователя:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Установить пароль:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>ID пользователя:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Главная группа:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Командная оболочка:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Домашний каталог:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="67"/>
        <source>Change password:</source>
        <translation>Изменить пароль:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <location filename="../../../userdialog.cpp" line="141"/>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <source>The user ID is in use.</source>
        <translation>Пользовательский ID уже используется.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="141"/>
        <source>The user name cannot be empty.</source>
        <translation>Имя пользователя не может быть пустым.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>The user name is in use.</source>
        <translation>Имя пользователя уже используется.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Вы действительно хотите использовать пустой пароль для этого пользователя?</translation>
    </message>
</context>
</TS>
